@@ -1,24 +1,33 @@
+import re
 from .logger import Logger
 from .config import Configs
 from .providers import StoreProvider, Providers
 from .stages import Stages
+from .constants import *
+from .exceptions import *
 
 class SecretProvider(StoreProvider):
-    def list(self, stage, uninherited, format, decrypt):
+    def add(self, project, application, stage, key, value):
         raise NotImplementedError()
-    def add(self, stage, key, value):
+    def list(self, project, application, stage, uninherited, decrypt):
         raise NotImplementedError()
-    def delete(self, stage, key):
+    def get(self, project, application, stage, key, revision=None):
         raise NotImplementedError()
-    def get(self, stage, key):
+    def delete(self, project, application, stage, key):
+        raise NotImplementedError()
+    def history(self, project, application, stage, key):
         raise NotImplementedError()
 
 class SecretManager():
 
     def validate_key(self, key):
-        provider = Providers.SecretProvider()
         Logger.info("Start validating secret key...")
-        return provider.validate_key(key)
+        Logger.debug(f"Validating: key={key}")
+        pattern = REGEX_PATTERNS['secret_key']
+        if not re.match(pattern, key):
+            raise DSOException(MESSAGES['InvalidKeyPattern'].format(key, pattern))
+        if '..' in key:
+            raise DSOException(MESSAGES['InvalidKeyStr'].format(key, '..'))
 
     def list(self, stage, uninherited, decrypt):
         project = Configs.project
